@@ -18,11 +18,13 @@ import hashlib
 import os
 
 from jinja2 import PackageLoader
-from shake import url_for
+from shake import url_for, Render
+
 
 DEFAULT_HASH_COST = 10
 
 auth_loader = PackageLoader('shake_auth', 'views')
+auth_render = Render(loader=auth_loader)
 
 
 class LazyUser(object):
